@@ -1,5 +1,5 @@
 # koboldfs
-# Copyright (C) 2008-2009 Fabio Tranchitella <fabio@tranchitella.it>
+# Copyright (C) 2008-2010 Tranchitella Kft. <http://tranchtella.eu>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-VERSION             = '0.2'
+VERSION             = '0.3'
 BLOCKSIZE           = 1024*1024
 
 RES_REDIRECT        = '\x00'
@@ -34,3 +34,7 @@ CMD_PUT             = '\x11'
 CMD_GET             = '\x12'
 CMD_GET_URL         = '\x13'
 CMD_DELETE          = '\x14'
+
+CMD_PREPARE         = '\x20'
+CMD_COMMIT          = '\x21'
+CMD_ABORT           = '\x22'
