@@ -34,6 +34,7 @@ import threading
 import logging
 import logging.handlers
 
+from ConfigParser import ConfigParser
 from datetime import datetime
 
 from sqlalchemy import and_, create_engine
@@ -372,6 +373,7 @@ class ServerChannel(asyncore.dispatcher):
         url = domain[3] % {
             'filename': filename, 'domain': domain[1], 'server': replica[2],
         }
+        url = url.encode('utf-8')
         # reset the status
         self._buffer += protocol.RES_TRANSFER + \
             struct.pack('I', len(url)) + url
@@ -685,12 +687,18 @@ class ServerHandler(object):
         if not os.path.isfile(options.config):
             print "Configuration file `%s' does not exist!" % options.config
             sys.exit(1)
-        for r in open(options.config):
-            r = r.strip()
-            if r.startswith('#') or '=' not in r:
-                continue
-            key, value = map(string.strip, r.split('=', 1))
-            setattr(options, key, value)
+        if options.config.endswith('.ini'):
+            config = ConfigParser()
+            config.read([options.config])
+            for key, value in config.items('koboldfs'):
+                setattr(options, key, value)
+        else:
+            for r in open(options.config):
+                r = r.strip()
+                if r.startswith('#') or '=' not in r:
+                    continue
+                key, value = map(string.strip, r.split('=', 1))
+                setattr(options, key, value)
 
     def start_logging(self, options):
         """Start logging infrastructure"""
